@@ -1,12 +1,18 @@
-
 /*
  *  defDirect.c
- *  $Id: defDirect.c,v 4.1 2005/01/01 00:12:17 bkorb Exp $
+ *  $Id: defDirect.c,v 4.10 2005/11/26 19:43:06 bkorb Exp $
  *  This module processes definition file directives.
+ *
+ *  blocksort spacing=2 \
+ *    output=defDirect-sorted.c \
+ *    input=defDirect.c \
+ *    pat='^/\*=directive' \
+ *    start='^doDir_IGNORE' \
+ *    trail='\+\+\+ End of Directives'
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,8 +27,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 tSCC zNoEndif[]   = "Definition error:  in %s line %d, #endif not found\n";
@@ -30,11 +36,10 @@ tSCC zNoMatch[]   = "Definition error:  in %s line %d, "
                     "#%s no matching start/if directive\n";
 tSCC zCheckList[] = "\n#";
 
-STATIC int  ifdefLevel = 0;
-STATIC teDirectives findDirective( char* pzDirName );
-STATIC teDirectives findDirective( char* pzDirName );
-STATIC char* skipToEndif( char* pzScan );
-STATIC char* skipToElseEnd( char* pzScan );
+static int  ifdefLevel = 0;
+
+static teDirectives
+findDirective( char* pzDirName );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
@@ -46,7 +51,7 @@ STATIC char* skipToElseEnd( char* pzScan );
  *  Decide what to do and return a pointer to the character
  *  where scanning is to resume.
  */
-EXPORT char*
+LOCAL char*
 processDirective( char* pzScan )
 {
     const tDirTable* pTbl  = dirTable;
@@ -141,7 +146,7 @@ processDirective( char* pzScan )
  *  count if it is a bogus name.
  */
 
-STATIC teDirectives
+static teDirectives
 findDirective( char* pzDirName )
 {
     teDirectives res = (teDirectives)0;
@@ -166,7 +171,7 @@ findDirective( char* pzDirName )
         }
 
         fprintf( pfTrace, "WARNING:  in %s on line %d unknown directive:\n"
-                 "\t#%s\n", pCurCtx->pzFileName, pCurCtx->lineNo, pzDirName );
+                 "\t#%s\n", pCurCtx->pzCtxFname, pCurCtx->lineNo, pzDirName );
 
         if (ch != NUL)
             pzDirName[32] = ch;
@@ -185,9 +190,12 @@ findDirective( char* pzDirName )
  *  accepting the preceeding text) or when encountering a "#if*def"
  *  while skipping a block of text due to a failed test.
  */
-STATIC char*
-skipToEndif( char* pzScan )
+static char*
+skipToEndif( char* pzStart )
 {
+    char* pzScan = pzStart;
+    char* pzRet;
+
     for (;;) {
         char*  pz;
         /*
@@ -200,7 +208,7 @@ skipToEndif( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
@@ -216,8 +224,9 @@ skipToEndif( char* pzScan )
              */
             char* pz = strchr( pzScan, '\n' );
             if (pz != NULL)
-                return pz+1;
-            return pzScan + strlen( pzScan );
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            goto leave;
         }
 
         case DIR_IFDEF:
@@ -235,19 +244,22 @@ skipToEndif( char* pzScan )
             break; /* ignore it */
         }  /* switch (findDirective( pzScan )) */
     }
+
+ leave:
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
 }
 
 
-/*
- *  skipToElseEnd
- *
- *  Skip through the text to a matching "#endif" or "#else" or
- *  "#elif*def".  We do this when we are skipping code due to a failed
- *  "#if*def" test.
- */
-STATIC char*
-skipToElseEnd( char* pzScan )
+static char*
+skipToEndmac( char* pzStart )
 {
+    char* pzScan = pzStart;
+    char* pzRet;
+
     for (;;) {
         char*  pz;
         /*
@@ -260,7 +272,60 @@ skipToElseEnd( char* pzScan )
         else {
             pz = strstr( pzScan, zCheckList );
             if (pz == NULL)
-                AG_ABEND( aprf( zNoEndif, pCurCtx->pzFileName,
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
+                                pCurCtx->lineNo ));
+
+            pzScan = pz + STRSIZE( zCheckList );
+        }
+
+        while (isspace( *pzScan )) pzScan++;
+
+        if (findDirective( pzScan ) == DIR_ENDMAC) {
+            /*
+             *  We found the endmac we are interested in
+             */
+            char* pz = strchr( pzScan, '\n' );
+            if (pz != NULL)
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            break;
+        }
+    }
+
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
+}
+
+
+/*
+ *  skipToElseEnd
+ *
+ *  Skip through the text to a matching "#endif" or "#else" or
+ *  "#elif*def".  We do this when we are skipping code due to a failed
+ *  "#if*def" test.
+ */
+static char*
+skipToElseEnd( char* pzStart )
+{
+    char* pzScan = pzStart;
+    char* pzRet;
+
+    for (;;) {
+        char*  pz;
+        /*
+         *  'pzScan' is pointing to the first character on a line.
+         *  Check for a directive on the current line before scanning
+         *  later lines.
+         */
+        if (*pzScan == '#')
+            pz = ++pzScan;
+        else {
+            pz = strstr( pzScan, zCheckList );
+            if (pz == NULL)
+                AG_ABEND( aprf( zNoEndif, pCurCtx->pzCtxFname,
                                 pCurCtx->lineNo ));
 
             pzScan = pz + STRSIZE( zCheckList );
@@ -286,8 +351,9 @@ skipToElseEnd( char* pzScan )
              */
             char* pz = strchr( pzScan, '\n' );
             if (pz != NULL)
-                return pz+1;
-            return pzScan + strlen( pzScan );
+                 pzRet = pz+1;
+            else pzRet = pzScan + strlen( pzScan );
+            goto leave;
         }
 
         case DIR_IFDEF:
@@ -307,6 +373,13 @@ skipToElseEnd( char* pzScan )
             break;
         }  /* switch (findDirective( pzScan )) */
     }
+
+ leave:
+    while (pzStart < pzRet) {
+        if (*(pzStart++) == '\n')
+            pCurCtx->lineNo++;
+    }
+    return pzRet;
 }
 
 
@@ -323,7 +396,7 @@ skipToElseEnd( char* pzScan )
  *  needs or may take arguments (e.g. '#define'), then there should
  *  also be an 'arg:' section describing the argument(s).
  */
-STATIC char*
+static char*
 doDir_IGNORE( char* pzArg, char* pzScan )
 {
     return pzScan;
@@ -348,7 +421,7 @@ doDir_IGNORE( char* pzArg, char* pzScan )
  *  After the definitions file has been processed, any remaining entries
  *  in the define list will be added to the environment.
 =*/
-STATIC char*
+static char*
 doDir_define( char* pzArg, char* pzScan )
 {
     char*  pzName = pzArg;
@@ -375,16 +448,19 @@ doDir_define( char* pzArg, char* pzScan )
      *       directive itself, giving us the space needed.
      */
     if (! isspace( *pzArg )) {
-        pzName--;
+        char* pzS = pzName;
+        char* pzD = --pzName;
+
         *pzArg = NUL;
-        strcpy( pzName, pzName+1 );
-        strcat( pzName, "=" );
+        while ((*(pzD++) = *(pzS++)) != NUL)   ;
+        pzD[-1] = '=';
+        pzD[ 0] = NUL;
 
     } else {
         /*
          *  Otherwise, insert the '=' and move any data up against it.
-         *  We only accept one space separated token.  We are not
-         *  ANSI-C compliant.  ;-)
+         *  We only accept one name-type, space separated token.
+         *  We are not ANSI-C.  ;-)
          */
         char*  pz = pzArg+1;
         *pzArg++ = '=';
@@ -393,7 +469,7 @@ doDir_define( char* pzArg, char* pzScan )
         for (;;) {
             if ((*pzArg++ = *pz++) == NUL)
                 break;
-            if (isspace( *pz )) {
+            if (! ISNAMECHAR( *pz )) {
                 *pzArg = NUL;
                 break;
             }
@@ -412,13 +488,13 @@ doDir_define( char* pzArg, char* pzScan )
  *  otherwise it will generate an error.
  *  It will be ignored.
 =*/
-STATIC char*
+static char*
 doDir_elif( char* pzArg, char* pzScan )
 {
     tSCC z[] =
         "`#elif' directive encountered out of context\n\tin %s on line %d\n";
 
-    AG_ABEND( aprf( z, pCurCtx->pzFileName, pCurCtx->lineNo ));
+    AG_ABEND( aprf( z, pCurCtx->pzCtxFname, pCurCtx->lineNo ));
     /* NOTREACHED */
     return NULL;
 }
@@ -431,11 +507,11 @@ doDir_elif( char* pzArg, char* pzScan )
  *  If it follows the @code{#if}, then it will be ignored.  Otherwise,
  *  it will change the processing state to the reverse of what it was.
 =*/
-STATIC char*
+static char*
 doDir_else( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                         "else" ));
 
     return skipToEndif( pzScan );
@@ -448,30 +524,45 @@ doDir_else( char* pzArg, char* pzScan )
  *  This must follow an @code{#if}, @code{#ifdef} or @code{#ifndef}.
  *  In all cases, this will resume normal processing of text.
 =*/
-STATIC char*
+static char*
 doDir_endif( char* pzArg, char* pzScan )
 {
     if (--ifdefLevel < 0)
-        AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+        AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                         "endif" ));
 
     return pzScan;
 }
 
 
+/*=directive endmac
+ *
+ *  text:
+ *  This terminates a "macdef", but must not ever be encountered directly.
+=*/
+static char*
+doDir_endmac( char* pzArg, char* pzScan )
+{
+    AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
+                    "endmac" ));
+    /* NOTREACHED */
+    return NULL;
+}
+
+
 /*=directive endshell
  *
  *  text:
  *  Ends the text processed by a command shell into autogen definitions.
 =*/
-STATIC char*
+static char*
 doDir_endshell( char* pzArg, char* pzScan )
 {
     /*
      *  In actual practice, the '#endshell's must be consumed inside
      *  the 'doDir_shell()' procedure.
      */
-    AG_ABEND( aprf( zNoMatch, pCurCtx->pzFileName, pCurCtx->lineNo,
+    AG_ABEND( aprf( zNoMatch, pCurCtx->pzCtxFname, pCurCtx->lineNo,
                     "endshell" ));
     /* NOTREACHED */
     return NULL;
@@ -486,11 +577,11 @@ doDir_endshell( char* pzArg, char* pzScan )
  *  This directive will cause AutoGen to stop processing
  *  and exit with a status of EXIT_FAILURE.
 =*/
-STATIC char*
+static char*
 doDir_error( char* pzArg, char* pzScan )
 {
     AG_ABEND( aprf( "#error directive -- in %s on line %d\n\t%s\n",
-                    pCurCtx->pzFileName, pCurCtx->lineNo, pzArg ));
+                    pCurCtx->pzCtxFname, pCurCtx->lineNo, pzArg ));
     /* NOTREACHED */
     return NULL;
 }
@@ -510,7 +601,7 @@ doDir_error( char* pzArg, char* pzScan )
  *  @code{#if} expressions are not analyzed.  @strong{Everything} from here
  *  to the matching @code{#endif} is skipped.
 =*/
-STATIC char*
+static char*
 doDir_if( char* pzArg, char* pzScan )
 {
     return skipToEndif( pzScan );
@@ -524,12 +615,12 @@ doDir_if( char* pzArg, char* pzScan )
  *  text:
  *  The definitions that follow, up to the matching @code{#endif} will be
  *  processed only if there is a corresponding @code{-Dname} command line
- *  option.
+ *  option or if a @code{#define} of that name has been previously encountered.
 =*/
-STATIC char*
+static char*
 doDir_ifdef( char* pzArg, char* pzScan )
 {
-    if (getDefine( pzArg ) == NULL)
+    if (getDefine( pzArg, AG_FALSE ) == NULL)
         return skipToElseEnd( pzScan );
     ifdefLevel++;
     return pzScan;
@@ -545,10 +636,10 @@ doDir_ifdef( char* pzArg, char* pzScan )
  *  processed only if there is @strong{not} a corresponding @code{-Dname}
  *  command line option or there was a canceling @code{-Uname} option.
 =*/
-STATIC char*
+static char*
 doDir_ifndef( char* pzArg, char* pzScan )
 {
-    if (getDefine( pzArg ) != NULL)
+    if (getDefine( pzArg, AG_FALSE ) != NULL)
         return skipToElseEnd( pzScan );
     ifdefLevel++;
     return pzScan;
@@ -565,7 +656,7 @@ doDir_ifndef( char* pzArg, char* pzScan )
  *  double quotes or angle brackets (as in a C program), then the
  *  include is ignored.
 =*/
-STATIC char*
+static char*
 doDir_include( char* pzArg, char* pzScan )
 {
     tSCC*      apzSfx[] = { "def", NULL };
@@ -628,7 +719,7 @@ doDir_include( char* pzArg, char* pzScan )
      */
     pCtx->pCtx       = pCurCtx;
     pCurCtx          = pCtx;
-    AGDUPSTR( pCtx->pzFileName, zFullName, "def file name" );
+    AGDUPSTR( pCtx->pzCtxFname, zFullName, "def file name" );
 
     pCtx->pzScan     =
     pCtx->pzData     =
@@ -665,6 +756,12 @@ doDir_include( char* pzArg, char* pzScan )
 }
 
 
+/*=directive let
+ *
+ *  dummy:  let directives are ignored.
+=*/
+
+
 /*=directive line
  *
  *  text:
@@ -675,7 +772,7 @@ doDir_include( char* pzArg, char* pzScan )
  *  file and approximate line number of any errors found in extracted
  *  definitions.
 =*/
-STATIC char*
+static char*
 doDir_line( char* pzArg, char* pzScan )
 {
     /*
@@ -702,13 +799,26 @@ doDir_line( char* pzArg, char* pzScan )
             return pzScan;
         *pz = NUL;
     }
-    AGFREE( (void*)pCurCtx->pzFileName );
-    AGDUPSTR( pCurCtx->pzFileName, pzArg, "#line file name" );
+
+    AGDUPSTR( pCurCtx->pzCtxFname, pzArg, "#line file name" );
 
     return pzScan;
 }
 
 
+/*=directive macdef
+ *
+ *  text:
+ *  This is a new AT&T research preprocessing directive.  Basically, it is
+ *  a multi-line #define that may include other preprocessing directives.
+=*/
+static char*
+doDir_macdef( char* pzArg, char* pzScan )
+{
+    return skipToEndmac( pzScan );
+}
+
+
 /*=directive option
  *
  *  arg:  opt-name [ <text> ]
@@ -732,7 +842,7 @@ doDir_line( char* pzArg, char* pzScan )
  *  directories supplied in this way will be searched before any supplied on
  *  the command line.
 =*/
-STATIC char*
+static char*
 doDir_option( char* pzArg, char* pzScan )
 {
     optionLoadLine( &autogenOptions, pzArg );
@@ -754,7 +864,7 @@ doDir_option( char* pzArg, char* pzScan )
  *  process that handles the back-quoted @code{`} text.
  *  @strong{CAUTION}@:  let not your @code{$SHELL} be @code{csh}.
 =*/
-STATIC char*
+static char*
 doDir_shell( char* pzArg, char* pzScan )
 {
     tSCC       zShellText[] = "Computed Definitions";
@@ -777,12 +887,18 @@ doDir_shell( char* pzArg, char* pzScan )
     if (strncmp( pzText, zEndShell+1, STRSIZE( zEndShell )-1) == 0)
         return pzScan;
 
-    pzScan = strstr( pzScan, zEndShell );
-    if (pzScan == NULL)
-        AG_ABEND( aprf( "Missing #endshell after '#shell' in %s on line %d\n",
-                        pCurCtx->pzFileName, pCurCtx->lineNo ));
+    {
+        char* pz = strstr( pzScan, zEndShell );
+        if (pz == NULL)
+            AG_ABEND( aprf("Missing #endshell after '#shell' in %s on line %d\n",
+                           pCurCtx->pzCtxFname, pCurCtx->lineNo ));
 
-    *pzScan = NUL;
+        while (pzScan < pz) {
+            if (*(pzScan++) == '\n') pCurCtx->lineNo++;
+        }
+
+        *pzScan = NUL;
+    }
 
     /*
      *  Advance the scan pointer to the next line after '#endshell'
@@ -799,7 +915,7 @@ doDir_shell( char* pzArg, char* pzScan )
     pCurCtx->pzScan  = pzScan;
 
     if (pzShellProgram == NULL)
-        pzShellProgram = getDefine( zShellEnv );
+        pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
     /*
      *  Run the shell command.  The output text becomes the
@@ -827,7 +943,7 @@ doDir_shell( char* pzArg, char* pzScan )
     /*
      *  Set up the rest of the context structure
      */
-    AGDUPSTR( pCtx->pzFileName, zShellText, "shell text" );
+    AGDUPSTR( pCtx->pzCtxFname, zShellText, "shell text" );
     pCtx->pzScan     =
     pCtx->pzData     = (char*)(pCtx+1);
     pCtx->lineNo     = 0;
@@ -846,13 +962,14 @@ doDir_shell( char* pzArg, char* pzScan )
  *  Will remove any entries from the define list
  *  that match the undef name pattern.
 =*/
-STATIC char*
+static char*
 doDir_undef( char* pzArg, char* pzScan )
 {
     SET_OPT_UNDEFINE( pzArg );
     return pzScan;
 }
 
+
 /*+++ End of Directives +++*/
 /*
  * Local Variables:
