@@ -1,5 +1,5 @@
 /*
- *  $Id: defFind.c,v 4.3 2005/01/24 00:00:31 bkorb Exp $
+ *  $Id: defFind.c,v 4.6 2005/11/25 19:00:27 bkorb Exp $
  *
  *  This module locates definitions.
  */
@@ -20,8 +20,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 struct defEntryList {
@@ -34,7 +34,7 @@ typedef struct defEntryList tDefEntryList;
 
 tSCC zNameRef[]   = "Ill formed name ``%s'' in %s line %d\n";
 
-tSC zDefinitionName[ MAXPATHLEN ];
+static char zDefinitionName[ MAXPATHLEN ];
 
 static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
@@ -120,7 +120,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
         {
             char  svch = *pzScan;
             *pzScan = NUL;
-            pzVal    = getDefine( pzDef );
+            pzVal   = getDefine( pzDef, AG_TRUE );
             *pzScan = svch;
         }
 
@@ -421,7 +421,7 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
     breakCh  = *pcBrace;
     *pcBrace = NUL;
 
-    *pIsIndexed |= (breakCh == '[');
+    if (breakCh == '[') *pIsIndexed = AG_TRUE;
 
     for (;;) {
         /*
