@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expOutput.c,v 4.3 2005/01/24 00:00:32 bkorb Exp $
+ *  $Id: expOutput.c,v 4.7 2005/12/05 20:51:37 bkorb Exp $
  *
  *  This module implements the output file manipulation function
  */
@@ -21,8 +21,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 #ifndef S_IAMB
@@ -129,9 +129,9 @@ ag_scm_out_delete( void )
 SCM
 ag_scm_out_move( SCM new_file )
 {
-    size_t sz = SCM_LENGTH( new_file );
+    size_t sz = AG_SCM_STRLEN( new_file );
     char*  pz = (char*)AGALOC( sz + 1, "new file name string" );
-    memcpy( pz, SCM_CHARS( new_file ), sz );
+    memcpy( pz, AG_SCM_CHARS( new_file ), sz );
     pz[ sz ] = NUL;
 
     rename( pCurFp->pzOutName, pz );
@@ -164,14 +164,16 @@ ag_scm_out_pop( SCM ret_contents )
     if (pCurFp->pPrev == NULL)
         AG_ABEND( "ERROR:  Cannot pop output with no output pushed\n" );
 
-    if (gh_boolean_p( ret_contents ) && SCM_NFALSEP( ret_contents )) {
+    if (AG_SCM_BOOL_P( ret_contents ) && SCM_NFALSEP( ret_contents )) {
         long pos = ftell( pCurFp->pFile );
-        res = scm_makstr( pos, 0 );
+
         if (pos != 0) {
+            char* pz = ag_scribble( pos );
             rewind( pCurFp->pFile );
-            if (fread( SCM_CHARS( res ), pos, 1, pCurFp->pFile ) != 1)
+            if (fread( pz, pos, 1, pCurFp->pFile ) != 1)
                 AG_ABEND( aprf( "Error %d (%s) rereading output\n",
                                 errno, strerror( errno )));
+            res = AG_SCM_STR2SCM( pz, pos );
         }
     }
 
@@ -270,13 +272,13 @@ ag_scm_out_push_add( SCM new_file )
     tFpStack* p;
     char*  pzNewFile;
 
-    if (! gh_string_p( new_file ))
+    if (! AG_SCM_STRING_P( new_file ))
         return SCM_UNDEFINED;
 
     {
-        size_t sz = SCM_LENGTH( new_file );
+        size_t sz = AG_SCM_STRLEN( new_file );
         pzNewFile = (char*)AGALOC( sz + 1, "append file name string" );
-        memcpy( pzNewFile, SCM_CHARS( new_file ), sz );
+        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
         pzNewFile[ sz ] = NUL;
     }
 
@@ -324,10 +326,10 @@ ag_scm_out_push_new( SCM new_file )
     p->pPrev = pCurFp;
     p->flags = FPF_FREE;
 
-    if (gh_string_p( new_file )) {
-        size_t sz = SCM_LENGTH( new_file );
+    if (AG_SCM_STRING_P( new_file )) {
+        size_t sz = AG_SCM_STRLEN( new_file );
         pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, SCM_CHARS( new_file ), sz );
+        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
         pzNewFile[ sz ] = NUL;
         unlink( pzNewFile );
         addWriteAccess( pzNewFile );
@@ -377,7 +379,7 @@ ag_scm_out_push_new( SCM new_file )
          *  Otherwise, anonymous output without --no-fmemopen being selected
          *  will get us here.
          */
-        p->pFile  = fmemopen( NULL, 0, "wb+" );
+        p->pFile  = ag_fmemopen( NULL, 0, "wb+" );
         pzNewFile = "in-mem buffer";
         p->flags |= FPF_STATIC_NM | FPF_NOUNLINK | FPF_NOCHMOD;
     }
@@ -412,12 +414,12 @@ ag_scm_out_switch( SCM new_file )
     struct utimbuf tbuf;
     char*  pzNewFile;
 
-    if (! gh_string_p( new_file ))
+    if (! AG_SCM_STRING_P( new_file ))
         return SCM_UNDEFINED;
     {
-        size_t sz = SCM_LENGTH( new_file );
+        size_t sz = AG_SCM_STRLEN( new_file );
         pzNewFile = (char*)AGALOC( sz + 1, "new file name string" );
-        memcpy( pzNewFile, SCM_CHARS( new_file ), sz );
+        memcpy( pzNewFile, AG_SCM_CHARS( new_file ), sz );
         pzNewFile[ sz ] = NUL;
     }
 
@@ -463,7 +465,7 @@ ag_scm_out_switch( SCM new_file )
 SCM
 ag_scm_out_depth( void )
 {
-    return gh_int2scm( outputDepth );
+    return AG_SCM_INT2SCM( outputDepth );
 }
 
 
@@ -480,7 +482,7 @@ ag_scm_out_name( void )
 {
     tFpStack* p = pCurFp;
     while (p->flags & FPF_UNLINK)  p = p->pPrev;
-    return gh_str02scm( (void*)p->pzOutName );
+    return AG_SCM_STR02SCM( (void*)p->pzOutName );
 }
 
 
@@ -514,7 +516,7 @@ ag_scm_out_line( void )
         fseek( pCurFp->pFile, svpos, SEEK_SET );
     } while(0);
 
-    return gh_int2scm( lineNum );
+    return AG_SCM_INT2SCM( lineNum );
 }
 
 /*
