@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcIf.c,v 4.5 2005/07/27 17:26:32 bkorb Exp $
+ *  $Id: funcIf.c,v 4.7 2005/12/05 20:51:37 bkorb Exp $
  *
  *  This module implements the _IF text function.
  */
@@ -106,6 +106,7 @@ eval_true( void )
  *  cindex:  conditional emit
  *  cindex:  if test
  *  handler_proc:
+ *  load_proc:
  *
  *  desc:
  *  Conditional block.  Its arguments are evaluated (@pxref{EXPR}) and
@@ -138,6 +139,7 @@ eval_true( void )
 /*=macfunc ENDIF
  *
  *  what:   Terminate the @code{IF} Template Block
+ *  in-context:
  *
  *  desc:
  *    This macro ends the @code{IF} function template block.
@@ -197,6 +199,7 @@ mFunc_If( tTemplate* pT, tMacro* pMac )
  *  cindex:  conditional emit
  *  cindex:  while test
  *  handler_proc:
+ *  load_proc:
  *
  *  desc:
  *  Conditionally repeated block.  Its arguments are evaluated (@pxref{EXPR})
@@ -220,6 +223,7 @@ mFunc_If( tTemplate* pT, tMacro* pMac )
 /*=macfunc ENDWHILE
  *
  *  what:   Terminate the @code{WHILE} Template Block
+ *  in-context:
  *
  *  desc:
  *    This macro ends the @code{WHILE} function template block.
@@ -260,6 +264,7 @@ mFunc_While( tTemplate* pT, tMacro* pMac )
 /*=macfunc ELIF
  *
  *  what:   Alternate Conditional Template Block
+ *  in-context:
  *
  *  desc:
  *    This macro must only appear after an @code{IF} function, and
@@ -287,6 +292,7 @@ mLoad_Elif( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 /*=macfunc ELSE
  *
  *  what:   Alternate Template Block
+ *  in-context:
  *
  *  desc:
  *    This macro must only appear after an @code{IF} function,
@@ -475,7 +481,7 @@ ag_scm_set_writable( SCM set )
         break;
 
     default:
-        if (gh_boolean_p( set ) && (set == SCM_BOOL_F))
+        if (AG_SCM_BOOL_P( set ) && (set == SCM_BOOL_F))
             CLEAR_OPT( WRITABLE );
         else
             SET_OPT_WRITABLE;
